Learn R Programming

TCGAbiolinks (version 1.0.10)

TCGAanalyze_DEA: Differentially expression analysis (DEA) using edgeR package.

Description

TCGAanalyze_DEA allows user to perform Differentially expression analysis (DEA), using edgeR package to identify differentially expressed genes (DEGs). It is possible to do a two-class analysis.

TCGAanalyze_DEA performs DEA using following functions from edgeR:

  1. edgeR::DGEList converts the count matrix into an edgeR object.
  2. edgeR::estimateCommonDisp each gene gets assigned the same dispersion estimate.
  3. edgeR::exactTest performs pair-wise tests for differential expression between two groups.
  4. edgeR::topTags takes the output from exactTest(), adjusts the raw p-values using the False Discovery Rate (FDR) correction, and returns the top differentially expressed genes.

Usage

TCGAanalyze_DEA(mat1, mat2, Cond1type, Cond2type, method = "exactTest", fdr.cut = 1, logFC.cut = 0)

Arguments

mat1
numeric matrix, each row represents a gene, each column represents a sample with Cond1type
mat2
numeric matrix, each row represents a gene, each column represents a sample with Cond2type
Cond1type
a string containing the class label of the samples in mat1 (e.g., control group)
Cond2type
a string containing the class label of the samples in mat2 (e.g., case group)
method
is 'glmLRT' (1) or 'exactTest' (2). (1) Fit a negative binomial generalized log-linear model to the read counts for each gene (2) Compute genewise exact tests for differences in the means between two groups of negative-binomially distributed counts.
fdr.cut
is a threshold to filter DEGs according their p-value corrected
logFC.cut
is a threshold to filter DEGs according their logFC

Value

table with DEGs containing for each gene logFC, logCPM, pValue,and FDR

Examples

Run this code
dataNorm <- TCGAbiolinks::TCGAanalyze_Normalization(dataBRCA, geneInfo)
dataFilt <- TCGAanalyze_Filtering(tabDF = dataBRCA, method = "quantile", qnt.cut =  0.25)
samplesNT <- TCGAquery_SampleTypes(colnames(dataFilt), typesample = c("NT"))
samplesTP <- TCGAquery_SampleTypes(colnames(dataFilt), typesample = c("TP"))
dataDEGs <- TCGAanalyze_DEA(dataFilt[,samplesNT],
                      dataFilt[,samplesTP],"Normal", "Tumor")

Run the code above in your browser using DataLab